@@ -31,6 +31,8 @@ __PACKAGE__->set_primary_key("id");
 
 1;
 
+
+
 __END__
 =pod
 
@@ -40,7 +42,30 @@ AtomMQ::Schema::Result::AtomMQEntry
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
+
+=head1 ACCESSORS
+
+=head2 id
+
+  data_type: 'integer'
+  is_nullable: 0
+  is_auto_increment: 1
+
+=head2 feed
+
+  data_type: 'text'
+  is_nullable: 1
+
+=head2 title
+
+  data_type: 'text'
+  is_nullable: 1
+
+=head2 content
+
+  data_type: 'text'
+  is_nullable: 1
 
 =head1 AUTHOR
 
